@@ -87,8 +87,8 @@ TEST_CASE("vector tile from simplified geojson")
             feature_reader.skip();
         }
     }
-    mapnik::vector_tile_impl::GeometryPBF<double> geoms(geom_itr, tile_x, tile_y, scale, -1*scale);
-    auto geom = mapnik::vector_tile_impl::decode_geometry(geoms, geometry_type, 2);
+    mapnik::vector_tile_impl::GeometryPBF geoms(geom_itr);
+    auto geom = mapnik::vector_tile_impl::decode_geometry<double>(geoms, geometry_type, 2, tile_x, tile_y, scale, -1.0 * scale);
 
     unsigned int n_err = 0;
     mapnik::projection wgs84("+init=epsg:4326",true);
